@@ -1,6 +1,7 @@
 require 'rubygems'
+require 'bundler/setup'
 require 'test/unit'
-require 'shoulda'
+require 'shoulda-context'
 
 $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
 $LOAD_PATH.unshift(File.dirname(__FILE__))
@@ -8,3 +9,9 @@ require 'pcaprub'
 
 class Test::Unit::TestCase
 end
+
+if RUBY_VERSION >= "1.9.2"
+  require 'coveralls'
+  Coveralls.wear!
+end
+
